@@ -48,9 +48,9 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
     tmp = NULL;
     obj = cluev->align_left_list;
 
-    while (obj) {
-		if (obj->parent == p) {
-			if (tmp) {
+    while ( obj ) {
+		if ( obj->parent == p ) {
+			if ( tmp ) {
 				tmp->next_aligned = HTML_CLUEALIGNED (obj)->next_aligned;
 				tmp = HTML_CLUEALIGNED (obj);
 			} else {
@@ -68,9 +68,9 @@ remove_aligned_by_parent ( HTMLClueV *cluev,
     tmp = NULL;
     obj = cluev->align_right_list;
 
-    while (obj) {
-		if (obj->parent == p) {
-			if (tmp) {
+    while ( obj ) {
+		if ( obj->parent == p ) {
+			if ( tmp ) {
 				tmp->next_aligned = HTML_CLUEALIGNED (obj)->next_aligned;
 				tmp = HTML_CLUEALIGNED (obj);
 			} else {
@@ -205,6 +205,7 @@ html_cluev_do_layout (HTMLObject *o, HTMLPainter *painter, gboolean calc_size, G
 		o->ascent = clue->curr->y;
 		lmargin = get_lmargin (o, painter);
 
+
 		if (calc_size)
 			changed |= html_object_calc_size (clue->curr, painter, changed_objs);
 
@@ -218,7 +219,7 @@ html_cluev_do_layout (HTMLObject *o, HTMLPainter *painter, gboolean calc_size, G
 				/* printf ("y: %d ", o->ascent - clue->curr->descent); */
 				if (first_change) {
 					first_change = FALSE;
-					/* if it's new one (y == 0) clear from new y_off, else from old one or new one,
+				        /* if it's new one (y == 0) clear from new y_off, else from old one or new one,
 					   which one is higher */
 					first_y_off = old_y && old_y_off < new_y_off ? old_y_off : new_y_off;
 					/* printf ("\nfirst_y_off: %d x %d --> %d\n", old_y_off, new_y_off, first_y_off); */
@@ -269,7 +270,7 @@ html_cluev_do_layout (HTMLObject *o, HTMLPainter *painter, gboolean calc_size, G
 			o->ascent = aclue->y + aclue->parent->y - aclue->parent->ascent;
 	}
 
-	if (!changed
+	if (! changed
 	    && (o->ascent != old_ascent || o->descent != old_descent || o->width != old_width))
 		changed = TRUE;
 
@@ -456,7 +457,7 @@ check_point (HTMLObject *self,
 	HTMLObject *p;
 	HTMLObject *obj;
 	HTMLClueAligned *clue;
-	gint padding = HTML_CLUEV (self)->padding;
+	int padding = HTML_CLUEV (self)->padding;
 
 	if (x < self->x || x >= self->x + self->width
 	    || y < self->y - self->ascent || y >= self->y + self->descent)
@@ -486,8 +487,8 @@ check_point (HTMLObject *self,
 		parent = HTML_OBJECT (clue)->parent;
 		obj = html_object_check_point (HTML_OBJECT (clue),
 					       painter,
-					       x - parent->x,
-					       y - parent->y + parent->ascent,
+					       x - HTML_OBJECT (clue)->parent->x,
+					       y - HTML_OBJECT (clue)->parent->y + HTML_OBJECT (clue)->parent->ascent,
 					       offset_return,
 					       for_cursor);
 		if (obj != NULL) {
@@ -503,8 +504,8 @@ check_point (HTMLObject *self,
 		parent = HTML_OBJECT (clue)->parent;
 		obj = html_object_check_point (HTML_OBJECT (clue),
 					       painter,
-					       x - parent->x,
-					       y - parent->y + parent->ascent,
+					       x - HTML_OBJECT (clue)->parent->x,
+					       y - HTML_OBJECT (clue)->parent->y + HTML_OBJECT (clue)->parent->ascent,
 					       offset_return,
 					       for_cursor);
 		if (obj != NULL) {
@@ -515,7 +516,7 @@ check_point (HTMLObject *self,
 	for (p = HTML_CLUE (self)->head; p != 0; p = p->next) {
 		gint x1, y1;
 
-		if (!for_cursor) {
+		if (! for_cursor) {
 			x1 = x;
 			y1 = y;
 		} else {
@@ -596,7 +597,7 @@ relayout (HTMLObject *self,
 		self->y = self->ascent;
 	} else {
 		/* Relayout our parent starting from us.  */
-		if (!html_object_relayout (self->parent, engine, self))
+		if (! html_object_relayout (self->parent, engine, self))
 			html_engine_queue_draw (engine, self);
 	}
 
